require './spec/spec_helper'

RSpec.describe Saper::Actions::ConvertToTime do
  let(:subject_without_tz) do
    Saper::Actions::ConvertToTime.new('%d-%m-%Y %H:%M')
  end
  let(:subject_with_tz) do
    Saper::Actions::ConvertToTime.new('%d-%m-%Y %H:%M', 'Europe/Moscow')
  end
  let(:input) do
    '19-04-2014 18:56'
  end
  context ".type" do
    it "returns convert_to_time" do
      expect(described_class.type).to eq 'convert_to_time'
    end
  end
  context ".accepts?(:atom)" do
    it "returns false" do
      expect(described_class.accepts?(:atom)).to be false
    end
  end
  context ".accepts?(:document)" do
    it "returns false" do
      expect(described_class.accepts?(:document)).to be false
    end
  end
  context ".accepts?(:html)" do
    it "returns false" do
      expect(described_class.accepts?(:html)).to be false
    end
  end
  context ".accepts?(:json)" do
    it "returns false" do
      expect(described_class.accepts?(:json)).to be false
    end
  end
  context ".accepts?(:markdown)" do
    it "returns false" do
      expect(described_class.accepts?(:markdown)).to be false
    end
  end
  context ".accepts?(:nothing)" do
    it "returns false" do
      expect(described_class.accepts?(:nothing)).to be false
    end
  end
  context ".accepts?(:text)" do
    it "returns true " do
      expect(described_class.accepts?(:text)).to be true
    end
  end
  context ".accepts?(:time)" do
    it "returns false" do
      expect(described_class.accepts?(:time)).to be false
    end
  end
  context ".accepts?(:url)" do
    it "returns false" do
      expect(described_class.accepts?(:url)).to be false
    end
  end
  context ".accepts?(:xml)" do
    it "returns false" do
      expect(described_class.accepts?(:xml)).to be false
    end
  end
  context ".output_for(:atom)" do
    it "returns :nothing" do
      expect(described_class.output_for(:atom)).to be :nothing
    end
  end
  context ".output_for(:document)" do
    it "returns :nothing" do
      expect(described_class.output_for(:document)).to be :nothing
    end
  end
  context ".output_for(:html)" do
    it "returns :nothing" do
      expect(described_class.output_for(:html)).to be :nothing
    end
  end
  context ".output_for(:json)" do
    it "returns :nothing" do
      expect(described_class.output_for(:json)).to be :nothing
    end
  end
  context ".output_for(:markdown)" do
    it "returns :nothing" do
      expect(described_class.output_for(:markdown)).to be :nothing
    end
  end
  context ".output_for(:text)" do
    it "returns :time" do
      expect(described_class.output_for(:text)).to be :time
    end
  end
  context ".output_for(:time)" do
    it "returns :nothing" do
      expect(described_class.output_for(:time)).to be :nothing
    end
  end
  context ".output_for(:url)" do
    it "returns :nothing" do
      expect(described_class.output_for(:url)).to be :nothing
    end
  end
  context ".output_for(:xml)" do
    it "returns :nothing" do
      expect(described_class.output_for(:xml)).to be :nothing
    end
  end
  context ".returns_multiple_items?" do
    it "returns false" do
      expect(described_class.returns_multiple_items?).to be false
    end
  end
  context ".new(nil, nil)" do
    it "raises InvalidArgument" do
      expect { described_class.new }.to raise_error Saper::InvalidArgument
    end
  end
  context ".new(format, nil)" do
    it "raises no errors" do
      expect { described_class.new("%H") }.to_not raise_error
    end
  end
  context ".new(Numeric)" do
    it "raises InvalidArgument" do
      expect { described_class.new(2) }.to raise_error Saper::InvalidArgument
    end
  end
  context ".new(Hash)" do
    it "raises InvalidArgumenth" do
      expect { described_class.new({}) }.to raise_error Saper::InvalidArgument
    end
  end
  context ".new(Array)" do
    it "raises InvalidArgument" do
      expect { described_class.new([]) }.to raise_error Saper::InvalidArgument
    end
  end
  context ".new(String)" do
    it "returns Action instance" do
      expect(described_class.new("!")).to be_a Saper::Action
    end
  end
  context "#run(nil)" do
    it "raises InvalidInput" do
      expect { subject_without_tz.run(nil) }.to raise_error Saper::InvalidInput
    end
  end
  context "#run(valid String)" do
    it "returns Time instance" do
      expect(subject_with_tz.run(input)).to be_a Saper::Items::Time
    end
    it "returns valid output with defined TZ" do
      expect(subject_with_tz.run(input).to_s).to eq '2014-04-19T18:56:00+04:00'
    end
    it "returns valid output with undefined TZ" do
      expect(subject_without_tz.run(input).to_s).to eq '2014-04-19T18:56:00+00:00'
    end
  end
  context "#run(invalid String)" do
    it "raises InvalidItem" do
      expect { subject_with_tz.run("ABCDEF") }.to raise_error Saper::InvalidItem
    end
  end
end