require './spec/spec_helper'

RSpec.describe Saper::Actions::GetAttribute do
  let :subject do
    Saper::Actions::GetAttribute.new("class")
  end
  let :html do
    Saper::Items::HTML.new('<div class="ok"></div>').find("div")
  end
  let :xml do
    Saper::Items::XML.new('<item class="ok"></item>').find("item")
  end
  context ".type" do
    it "returns get_attribute" do
      expect(described_class.type).to eq 'get_attribute'
    end
  end
  context ".accepts?(:atom)" do
    it "returns false" do
      expect(described_class.accepts?(:atom)).to be false
    end
  end
  context ".accepts?(:html)" do
    it "returns true" do
      expect(described_class.accepts?(:html)).to be true
    end
  end
  context ".accepts?(:json)" do
    it "returns false" do
      expect(described_class.accepts?(:json)).to be false
    end
  end
  context ".accepts?(:markdown)" do
    it "returns false" do
      expect(described_class.accepts?(:markdown)).to be false
    end
  end
  context ".accepts?(:nothing)" do
    it "returns false" do
      expect(described_class.accepts?(:nothing)).to be false
    end
  end
  context ".accepts?(:text)" do
    it "returns false" do
      expect(described_class.accepts?(:text)).to be false
    end
  end
  context ".accepts?(:time)" do
    it "returns false" do
      expect(described_class.accepts?(:time)).to be false
    end
  end
  context ".accepts?(:url)" do
    it "returns false" do
      expect(described_class.accepts?(:url)).to be false
    end
  end
  context ".accepts?(:xml)" do
    it "returns true" do
      expect(described_class.accepts?(:xml)).to be true
    end
  end
  context ".output_for(:atom)" do
    it "returns :nothing" do
      expect(described_class.output_for(:atom)).to be :nothing
    end
  end
  context ".output_for(:document)" do
    it "returns :nothing" do
      expect(described_class.output_for(:document)).to be :nothing
    end
  end
  context ".output_for(:html)" do
    it "returns :text" do
      expect(described_class.output_for(:html)).to be :text
    end
  end
  context ".output_for(:json)" do
    it "returns :nothing" do
      expect(described_class.output_for(:json)).to be :nothing
    end
  end
  context ".output_for(:markdown)" do
    it "returns :nothing" do
      expect(described_class.output_for(:markdown)).to be :nothing
    end
  end
  context ".output_for(:text)" do
    it "returns :nothing" do
      expect(described_class.output_for(:text)).to be :nothing
    end
  end
  context ".output_for(:time)" do
    it "returns :nothing" do
      expect(described_class.output_for(:time)).to be :nothing
    end
  end
  context ".output_for(:url)" do
    it "returns :nothing" do
      expect(described_class.output_for(:url)).to be :nothing
    end
  end
  context ".output_for(:xml)" do
    it "returns :text" do
      expect(described_class.output_for(:xml)).to be :text
    end
  end
  context ".returns_multiple_items?" do
    it "returns false" do
      expect(described_class.returns_multiple_items?).to be false
    end
  end
  context ".new(nil)" do
    it "raises InvalidArgument" do
      expect { described_class.new(nil) }.to raise_error Saper::InvalidArgument
    end
  end
  context ".new(Numeric)" do
    it "raises InvalidArgument" do
      expect { described_class.new(1) }.to raise_error Saper::InvalidArgument
    end
  end
  context ".new(Hash)" do
    it "raises InvalidArgument" do
      expect { described_class.new({}) }.to raise_error Saper::InvalidArgument
    end
  end
  context ".new(Array)" do
    it "raises InvalidArgument" do
      expect { described_class.new([]) }.to raise_error Saper::InvalidArgument
    end
  end
  context ".new(String)" do
    it "raises no errors" do
      expect { described_class.new("a") }.to_not raise_error
    end
  end
  context ".new(Text)" do
    it "raises no errors" do
      expect { described_class.new(Saper::Arguments::Text.new(:value => "a")) }.to_not raise_error
    end
  end
  context "#run(nil)" do
    it "raises InvalidInput" do
      expect { subject.run(nil) }.to raise_error(Saper::InvalidInput)
    end
  end
  context "#run(HTML)" do
    it "returns Text instance" do
      expect(subject.run(html)).to be_a Saper::Items::Text
    end
    it "returns valid output" do
      expect(subject.run(html)).to eq 'ok'
    end
  end
  context "#run(XML)" do
    it "returns Text instance" do
      expect(subject.run(xml)).to be_a Saper::Items::Text
    end
    it "returns valid output" do
      expect(subject.run(xml)).to eq 'ok'
    end
  end
end