require './spec/spec_helper'

RSpec.describe Saper::Actions::RemoveMatching do
  let :subject do
    Saper::Actions::RemoveMatching.new('abc')
  end
  context ".type" do
    it "returns remove_matching" do
      expect(described_class.type).to eq 'remove_matching'
    end
  end
  context ".accepts?(:atom)" do
    it "returns false" do
      expect(described_class.accepts?(:atom)).to be false
    end
  end
  context ".accepts?(:html)" do
    it "returns false" do
      expect(described_class.accepts?(:html)).to be false
    end
  end
  context ".accepts?(:json)" do
    it "returns false" do
      expect(described_class.accepts?(:json)).to be false
    end
  end
  context ".accepts?(:markdown)" do
    it "returns false" do
      expect(described_class.accepts?(:markdown)).to be false
    end
  end
  context ".accepts?(:nothing)" do
    it "returns false" do
      expect(described_class.accepts?(:nothing)).to be false
    end
  end
  context ".accepts?(:text)" do
    it "returns true" do
      expect(described_class.accepts?(:text)).to be true
    end
  end
  context ".accepts?(:time)" do
    it "returns false" do
      expect(described_class.accepts?(:time)).to be false
    end
  end
  context ".accepts?(:url)" do
    it "returns false" do
      expect(described_class.accepts?(:url)).to be false
    end
  end
  context ".accepts?(:xml)" do
    it "returns false" do
      expect(described_class.accepts?(:xml)).to be false
    end
  end
  context ".output_for(:atom)" do
    it "returns :nothing" do
      expect(described_class.output_for(:atom)).to be :nothing
    end
  end
  context ".output_for(:document)" do
    it "returns :nothing" do
      expect(described_class.output_for(:document)).to be :nothing
    end
  end
  context ".output_for(:html)" do
    it "returns :nothing" do
      expect(described_class.output_for(:html)).to be :nothing
    end
  end
  context ".output_for(:json)" do
    it "returns :nothing" do
      expect(described_class.output_for(:json)).to be :nothing
    end
  end
  context ".output_for(:markdown)" do
    it "returns :nothing" do
      expect(described_class.output_for(:markdown)).to be :nothing
    end
  end
  context ".output_for(:text)" do
    it "returns :text" do
      expect(described_class.output_for(:text)).to be :text
    end
  end
  context ".output_for(:time)" do
    it "returns :nothing" do
      expect(described_class.output_for(:time)).to be :nothing
    end
  end
  context ".output_for(:url)" do
    it "returns :nothing" do
      expect(described_class.output_for(:url)).to be :nothing
    end
  end
  context ".output_for(:xml)" do
    it "returns :nothing" do
      expect(described_class.output_for(:xml)).to be :nothing
    end
  end
  context ".returns_multiple_items?" do
    it "returns false" do
      expect(described_class.returns_multiple_items?).to be false
    end
  end
  context ".new(nil)" do
    it "raises InvalidArgument" do
      expect { described_class.new }.to raise_error Saper::InvalidArgument
    end
  end
  context ".new(Numeric)" do
    it "raises InvalidArgument" do
      expect { described_class.new(2) }.to raise_error Saper::InvalidArgument
    end
  end
  context ".new(Hash)" do
    it "raises InvalidArgumenth" do
      expect { described_class.new({}) }.to raise_error Saper::InvalidArgument
    end
  end
  context ".new(Array)" do
    it "raises InvalidArgument" do
      expect { described_class.new([]) }.to raise_error Saper::InvalidArgument
    end
  end
  context ".new(String)" do
    it "returns Action instance" do
      expect(described_class.new("!")).to be_a Saper::Action
    end
  end
  context ".new(Text)" do
    it "returns Action instance" do
      expect(described_class.new(Saper::Arguments::Text.new(:value => "!"))).to be_a Saper::Action
    end
  end
  context "#run(nil)" do
    it "raises InvalidInput" do
      expect { subject.run(nil) }.to raise_error Saper::InvalidInput
    end
  end
  context "#run(Numeric)" do
    it "returns valid output" do
      expect { subject.run(1) }.to raise_error Saper::InvalidInput
    end
  end
  context "#run(matching String)" do
    it "returns nil" do
      expect(subject.run('abc')).to be_a Saper::Items::Nothing
    end
  end
  context "#run(non-matching String)" do
    it "returns Text instance" do
      expect(subject.run('xyz')).to be_a Saper::Items::Text
    end
  end
  context "#run(matching Text)" do
    it "returns nil" do
      expect(subject.run(Saper::Items::Text.new('abc'))).to be_a Saper::Items::Nothing
    end
  end
  context "#run(non-matching Text)" do
    it "returns Text instance" do
      expect(subject.run(Saper::Items::Text.new('xyz'))).to be_a Saper::Items::Text
    end
  end
end