require './spec/spec_helper'

RSpec.describe Saper::Argument do
  context ".new(:text, nil)" do
    it "raises InvalidArgument" do
      expect { Saper::Argument.new(:text, :value => nil) }.to raise_error Saper::InvalidArgument
    end
  end
  context ".new(:text)" do
    it "raises InvalidArgument" do
      expect { Saper::Argument.new(:text) }.to raise_error Saper::InvalidArgument
    end
  end
  context ".new(:text, invalid)" do
    it "raises InvalidArgument" do
      expect { Saper::Argument.new(:text, :value => 1) }.to raise_error Saper::InvalidArgument
    end
  end
  context ".new(:text, valid)" do
    it "raises no exceptions" do
      expect(Saper::Argument.new(:text, :value => "text")).to be_a Saper::Argument
    end
  end
  context ".new(:text, optional)" do
    it "raises no exceptions" do
      expect(Saper::Argument.new(:text, :optional => true)).to be_a Saper::Argument
    end
  end
  context ".new(:text, optional, invalid)" do
    it "raises InvalidArgument" do
      expect { Saper::Argument.new(:text, :optional => true, :value => 1) }.to raise_error Saper::InvalidArgument
    end
  end
  context ".new(:text, optional, valid)" do
    it "returns Action instance" do
      expect(Saper::Argument.new(:text, :optional => true, :value => "text")).to be_a Saper::Argument
    end
  end
  context "#set(invalid)" do
    it "raises InvalidArgument" do
      expect { Saper::Argument.new(:text, :value => "text").set(1) }.to raise_error Saper::InvalidArgument
    end
  end
  context "#set(optional invalid)" do
    it "raises InvalidArgument" do
      expect { Saper::Argument.new(:text, :optional => true, :value => "text").set(1) }.to raise_error Saper::InvalidArgument
    end
  end
  context "#set(valid)" do
    it "returns self" do
      expect(Saper::Argument.new(:text, :optional => true).set("text")).to be_a Saper::Argument
    end
  end
  context "#value" do
    it "returns nil by default" do
      expect(Saper::Argument.new(:text, :optional => true).value).to be_nil
    end
    it "returns stored value" do
      expect(Saper::Argument.new(:text, :value => "text").value).to eq "text"
    end
  end
  context "#optional?" do
    it "returns false by default" do
      expect(Saper::Argument.new(:text, :value => "text")).to_not be_optional
    end
    it "returns true if optionality flag is set" do
      expect(Saper::Argument.new(:text, :optional => true)).to be_optional
    end
  end
end