require './spec/spec_helper'

RSpec.describe Saper::Recipe do
  let :subject do
    Saper::Recipe.new
  end
  context ".unserialize(Hash)" do
    it "returns a Recipe instance" do
      expect(Saper::Recipe.unserialize({ :id => 0 })).to be_a Saper::Recipe
    end
  end
  context ".unserialize(Array)" do
    it "returns an Array" do
      expect(Saper::Recipe.unserialize([{ :id => 0 }, { :id => 1 }])).to be_a Array
    end
  end
  context ".unserialize(nil)" do
    it "raises InvalidRecipe" do
      expect { Saper::Recipe.unserialize(nil) }.to raise_error Saper::InvalidRecipe
    end
  end
  context "#id" do
    it "returns recipe ID" do
      expect(subject.id).to be_a(String)
    end
  end
  context "#actions" do
    it "returns an empty array by default" do
      expect(subject.actions).to eq []
    end
  end
  context "#<<(action)" do
    it "returns self" do
      expect(Saper::Recipe.new << Saper::Action.new(:nothing)).to be_a Saper::Recipe
    end
  end
  context "#<<(invalid)" do
    it "raises ActionExpected" do
      expect { Saper::Recipe.new << 'not an action' }.to raise_error Saper::ActionExpected
    end
  end
  context "#push(action)" do
    it "returns self" do
      expect(Saper::Recipe.new.push(Saper::Action.new(:nothing))).to be_a Saper::Recipe
    end
  end
  context "#push(invalid)" do
    it "raises ActionExpected" do
      expect { Saper::Recipe.new.push('not an action') }.to raise_error Saper::ActionExpected
    end
  end
  context "#empty?" do
    it "returns true by default" do
      expect(subject).to be_empty
    end
  end
  context "#multiple?" do
    it "returns false by default" do
      expect(subject).to_not be_multiple
    end
  end
  context "#requires" do
    it "returns empty array by default" do
      expect(subject.requires).to eq []
    end
  end
  context "#requires?" do
    it "returns false by default" do
      expect(subject.requires?).to be false
    end
  end
  context "#run" do
    it "returns Result instance" do
      expect(subject.run).to be_a Saper::Result
    end
  end
  context "#serialize" do
    it "returns a Hash" do
      expect(subject.serialize).to be_a Hash
    end
  end
  context "#to_string" do
    it "returns a string" do
      expect(subject.to_string).to be_a String
    end
  end
  context "#to_json" do
    it "returns a string" do
      expect(subject.to_json).to be_a String
    end
  end
end