require './spec/spec_helper'

RSpec.describe Saper::Runtime do
  let :subject do
    Saper::Runtime.new
  end
  context "#browser" do
    it "returns Browser instance" do
      expect(subject.browser).to be_a(Saper::Browser)
    end
  end
  context "#bytes_received" do
    it "returns zero by default" do
      expect(subject.bytes_received).to eq 0
    end
  end
  context "#bytes_sent" do
    it "returns zero by default" do
      expect(subject.bytes_sent).to eq 0
    end
  end
  context "#http_requests" do
    it "returns zero by default" do
      expect(subject.http_requests).to eq 0
    end
  end
  context "#keychain" do
    it "returns Keychain instance" do
      expect(subject.keychain).to be_a Saper::Keychain
    end
  end
  context "#credentials" do
    it "returns empty hash if service not found" do
      expect(subject.credentials(:services)).to eq({})
    end
  end
  context "#[]" do
    it "returns nil if variable is not defined" do
      expect(subject[:varname]).to be_nil
    end
  end
  context "#[]=" do
    it "stores variale value" do
      expect(Saper::Runtime.new { |r| r[:var] = 'A' }[:var]).to eq 'A'
    end
  end
  context "#variables" do
    it "returns list of variable names" do
      expect(Saper::Runtime.new { |r| r[:var] = 'B' }.variables).to eq({ :var => 'B' })
    end
  end
end