require './spec/spec_helper'

RSpec.describe Saper::Items::Document do
  let(:doc) do
    Saper::Items::Document.new("")
  end
  let(:doc_with_params) do
    Saper::Items::Document.new("", "http://google.com", { "content-type" => "text/html; charset=win-1251" })
  end
  it ".new(nil) raises InvalidItem" do
    expect { Saper::Items::Document.new(nil) }.to raise_error Saper::InvalidItem
  end
  it "#uri returns nil by default" do
    expect(doc.uri).to be_nil
  end
  it "#uri returns URI when defined" do
    expect(doc_with_params.uri).to eq "http://google.com"
  end
  it "#mime returns nil by default" do
    expect(doc.mime).to be_nil
  end
  it "#mime returns mime type if defined in headers" do
    expect(doc_with_params.mime).to eq "text/html"
  end
  it "#charset returns nil by defaukt" do
    expect(doc.charset).to be_nil
  end
  it "#charset returns charset if defined in headers" do
    expect(doc_with_params.charset).to eq "win-1251"
  end
end

RSpec.describe "Saper::Items::Document(empty String)" do
  subject do
    Saper::Items::Document.new("")
  end
  it "#size returns zero" do
    expect(subject.size).to eq 0
  end
  it "#to_html raises InvalidItem" do
    expect { subject.to_html }.to raise_error Saper::InvalidItem
  end
  it "#to_markdown raises InvalidItem" do
    expect { subject.to_markdown }.to raise_error Saper::InvalidItem
  end
  it "#to_native returns empty string" do
    expect(subject.to_native).to eq ""
  end
  it "#to_text returns Text" do
    expect(subject.to_text).to be_a Saper::Items::Text
  end
  it "#to_xml raises InvalidItem" do
    expect { subject.to_xml }.to raise_error Saper::InvalidItem
  end
end

RSpec.describe "Saper::Items::Document(HTML as String)" do
  subject do
    Saper::Items::Document.new("<html></html>")
  end
  it "#size returns string length" do
    expect(subject.size).to eq 13
  end
  it "#to_html returns HTML" do
    expect(subject.to_html).to be_a Saper::Items::HTML
  end
  it "#to_markdown returns Markdown" do
    expect(subject.to_markdown).to be_a Saper::Items::Markdown
  end
  it "#to_native returns document contents" do
    expect(subject.to_native).to eq "<html></html>"
  end
  it "#to_text returns Text" do
    expect(subject.to_text).to be_a Saper::Items::Text
  end
  it "#to_xml raises InvalidItem" do
    expect(subject.to_xml).to be_a Saper::Items::XML
  end
end

RSpec.describe "Saper::Items::Document(XML as String)" do
  subject do
    Saper::Items::Document.new("<response></response>")
  end
  it "#size returns string length" do
    expect(subject.size).to eq 21
  end
  it "#to_html returns HTML" do
    expect(subject.to_html).to be_a Saper::Items::HTML
  end
  it "#to_markdown returns Markdown" do
    expect(subject.to_markdown).to be_a Saper::Items::Markdown
  end
  it "#to_native returns document contents" do
    expect(subject.to_native).to eq "<response></response>"
  end
  it "#to_text returns Text" do
    expect(subject.to_text).to be_a Saper::Items::Text
  end
  it "#to_xml returns XML" do
    expect(subject.to_xml).to be_a Saper::Items::XML
  end
end