require './spec/spec_helper'

RSpec.describe Saper::Items::HTML do
  let :html do
    "<html><body><p><a href=\"http://google.com\">Google</a></p><p><a href=\"http://yandex.ru\">Yandex</a></p></body></html>"
  end
  let :subject do
    Saper::Items::HTML.new html
  end
  context ".new(nil)" do
    it "raises InvalidItem" do
      expect { Saper::Items::HTML.new(nil) }.to raise_error Saper::InvalidItem
    end
  end
  context ".new('')" do
    it "raises InvalidItem" do
      expect { Saper::Items::HTML.new("") }.to raise_error Saper::InvalidItem
    end
  end
  context ".new(String)" do
    it "returns HTML" do
      expect(Saper::Items::HTML.new("string")).to be_a Saper::Items::HTML
    end
  end
  context "#find(valid)" do
    it "returns HTML" do
      expect(subject.find("a")).to be_a Saper::Items::HTML
    end
  end
  context "#find(invalid)" do
    it "returns nil" do
      expect(subject.find("li")).to be_nil
    end
  end
  context "#find_all(valid)" do
    it "returns an Array of HTML instances" do
      expect(subject.find_all("a").first).to be_a Saper::Items::HTML
    end
  end
  context "#find_all(invalid)" do
    it "returns an empty Array" do
      expect(subject.find_all("li")).to be_empty
    end
  end
  context "#[](valid)" do
    it "returns Text" do
      expect(subject.find("a")["href"]).to be_a Saper::Items::Text
    end
  end
  context "#[](invalid)" do
    it "returns nil" do
      expect(subject.find("a")["unknown"]).to be_nil
    end
  end
  context "#inner_html" do
    it "returns Text" do
      expect(subject.inner_html).to be_a Saper::Items::Text
    end
  end
  context "#inner_html" do
    it "returns valid contents" do
      expect(subject.inner_html).to eq html
    end
  end
  context "#inner_text" do
    it "returns Text" do
      expect(subject.inner_text).to be_a Saper::Items::Text
    end
  end
  context "#remove_children_preserving_content" do
    it "returns modified HTML" do
      expect(subject.remove_children_preserving_content("a").to_native).to eq "<html><body><p>Google</p><p>Yandex</p></body></html>"
    end
  end
  context "#remove_children_with_content" do
    it "returns modified HTML" do
      expect(subject.remove_children_with_content("a").to_native).to eq "<html><body><p></p><p></p></body></html>"
    end
  end
  context "#to_markdown" do
    it "returns Markdown" do
      expect(subject.to_markdown).to be_a Saper::Items::Markdown
    end
  end
  context "#==" do
    it "returns true for matching string" do
      expect(subject.to_s).to eq html
    end
  end
end
