require './spec/spec_helper'

RSpec.describe Saper::Items::Time do
  let(:input) do
    '19-04-2014 18:56'
  end
  context ".new(nil)" do
    it "raises InvalidItem" do
      expect { Saper::Items::Time.new(nil) }.to raise_error Saper::InvalidItem
    end
  end
  context ".new('')" do
    it "raises InvalidItem" do
      expect { Saper::Items::Time.new('') }.to raise_error Saper::InvalidItem
    end
  end
  context ".new(invalid)" do
    it "raises InvalidItem" do
      expect { Saper::Items::Time.new(input, '%H:%M') }.to raise_error Saper::InvalidItem
    end
  end
  context ".new(valid)" do
    it "returns Time instance" do
      expect(Saper::Items::Time.new(input, '%d-%m-%Y %H:%M')).to be_a Saper::Items::Time
    end
  end
  context ".new(valid)" do
    it "returns valid time" do
      expect(Saper::Items::Time.new(input, '%d-%m-%Y %H:%M').to_s).to eq '2014-04-19T18:56:00+00:00'
    end
  end
  context ".new(valid, tz)" do
    it "returns Time instance" do
      expect(Saper::Items::Time.new(input, '%d-%m-%Y %H:%M', 'Europe/Moscow').to_s).to eq '2014-04-19T18:56:00+04:00'
    end
  end
  context "#to_native" do
    it "returns native Time instance" do
      expect(Saper::Items::Time.new(input, '%d-%m-%Y %H:%M').to_native).to be_a Time
    end
  end
end