require './spec/spec_helper'

RSpec.describe Saper::Items::XML do
  let :xml do
    "<response><item name=\"Google\"><host>google.com</host></item><item name=\"Yandex\"><host>yandex.ru</host></item></response>"
  end
  let :subject do
    Saper::Items::XML.new xml
  end
  context ".new(nil)" do
    it "raises InvalidItem" do
      expect { Saper::Items::XML.new(nil) }.to raise_error Saper::InvalidItem
    end
  end
  context ".new('')" do
    it "raises InvalidItem" do
      expect { Saper::Items::XML.new("") }.to raise_error Saper::InvalidItem
    end
  end
  context ".new(invalid String)" do
    it "raises InvalidItem" do
      expect { Saper::Items::XML.new("string") }.to raise_error Saper::InvalidItem
    end
  end
  context ".new(valid String)" do
    it "returns XML" do
      expect(Saper::Items::XML.new("<node>string</node>")).to be_a Saper::Items::XML
    end
  end
  context "#find(valid)" do
    it "returns XML" do
      expect(subject.find("host")).to be_a Saper::Items::XML
    end
  end
  context "#find(invalid)" do
    it "returns nil" do
      expect(subject.find("smth")).to be_nil
    end
  end
  context "#find_all(valid)" do
    it "returns an Array of XML instances" do
      expect(subject.find_all("host").first).to be_a Saper::Items::XML
    end
  end
  context "#find_all(invalid)" do
    it "returns an empty Array" do
      expect(subject.find_all("smth")).to be_empty
    end
  end
  context "#[](valid)" do
    it "returns Text" do
      expect(subject.find("item")["name"]).to be_a Saper::Items::Text
    end
  end
  context "#[](invalid)" do
    it "returns nil" do
      expect(subject.find("item")["unknown"]).to be_nil
    end
  end
  context "#inner_xml" do
    it "returns Text" do
      expect(subject.inner_xml).to be_a Saper::Items::Text
    end
  end
  context "#inner_xml" do
    it "returns valid contents" do
      expect(subject.inner_xml).to eq xml
    end
  end
  context "#inner_text" do
    it "returns Text" do
      expect(subject.inner_text).to be_a Saper::Items::Text
    end
  end
  context "#remove_children_preserving_content" do
    it "returns modified HTML" do
      expect(subject.remove_children_preserving_content("host").to_native).to eq "<response><item name=\"Google\">google.com</item><item name=\"Yandex\">yandex.ru</item></response>"
    end
  end
  context "#remove_children_with_content" do
    it "returns modified HTML" do
      expect(subject.remove_children_with_content("host").to_native).to eq "<response><item name=\"Google\"></item><item name=\"Yandex\"></item></response>"
    end
  end
end
